==> org.Dm.eg.db_3.15.0.tar.gz: org.Dm.eg.db/man/org.Dm.egFLYBASECG.Rd <==
\name{org.Dm.egFLYBASECG}
\alias{org.Dm.egFLYBASECG}
\alias{org.Dm.egFLYBASECG2EG}
\title{Map FlyBase CG Acession numbers with Entrez Gene identifiers}  
\description{ 
  org.Dm.egFLYBASE is an R object that contains mappings between 
  Entrez Gene identifiers and FlyBase CG accession numbers.  These
  accessions are used by ensembl and supported by flybase.    
}

\details{
  This object is a simple mapping of Entrez Gene identifiers
  \url{https://www.ncbi.nlm.nih.gov/entrez/query.fcgi?db=gene} to Flybase
  CG accession numbers.

  Mappings were based on data provided by: Entrez Gene  
  ftp://ftp.ncbi.nlm.nih.gov/gene/DATA  
  With a date stamp from the source of: 2022-Mar17
}

\seealso{
  \itemize{
    \item \code{\link[AnnotationDbi]{AnnotationDb-class}} for use of
          the \code{select()} interface.
  }
}

\examples{
## select() interface:
## Objects in this package can be accessed using the select() interface
## from the AnnotationDbi package. See ?select for details.

## Bimap interface:
x <- org.Dm.egFLYBASECG
# Get the entrez gene IDs that are mapped to a Flybase CG ID
mapped_genes <- mappedkeys(x)
# Convert to a list
xx <- as.list(x[mapped_genes])
if(length(xx) > 0) {
  # Get the FlyBase CG IDs for the first five genes
  xx[1:5]
  # Get the first one
  xx[[1]]
}
#For the reverse map FLYBASECG2EG:
# Convert to a list
xx <- as.list(org.Dm.egFLYBASECG2EG)
if(length(xx) > 0){
   # Gets the entrez gene IDs for the first five FlyBase CG IDs
   xx[1:5]
   # Get the first one
   xx[[1]]
}
}
\keyword{datasets}

==> org.Dm.eg.db_3.16.0.tar.gz: org.Dm.eg.db/man/org.Dm.egFLYBASECG.Rd <==
\name{org.Dm.egFLYBASECG}
\alias{org.Dm.egFLYBASECG}
\alias{org.Dm.egFLYBASECG2EG}
\title{Map FlyBase CG Acession numbers with Entrez Gene identifiers}  
\description{ 
  org.Dm.egFLYBASE is an R object that contains mappings between 
  Entrez Gene identifiers and FlyBase CG accession numbers.  These
  accessions are used by ensembl and supported by flybase.    
}

\details{
  This object is a simple mapping of Entrez Gene identifiers
  \url{https://www.ncbi.nlm.nih.gov/entrez/query.fcgi?db=gene} to Flybase
  CG accession numbers.

  Mappings were based on data provided by: Entrez Gene  
  ftp://ftp.ncbi.nlm.nih.gov/gene/DATA  
  With a date stamp from the source of: 2022-Sep12
}

\seealso{
  \itemize{
    \item \code{\link[AnnotationDbi]{AnnotationDb-class}} for use of
          the \code{select()} interface.
  }
}

\examples{
## select() interface:
## Objects in this package can be accessed using the select() interface
## from the AnnotationDbi package. See ?select for details.

## Bimap interface:
x <- org.Dm.egFLYBASECG
# Get the entrez gene IDs that are mapped to a Flybase CG ID
mapped_genes <- mappedkeys(x)
# Convert to a list
xx <- as.list(x[mapped_genes])
if(length(xx) > 0) {
  # Get the FlyBase CG IDs for the first five genes
  xx[1:5]
  # Get the first one
  xx[[1]]
}
#For the reverse map FLYBASECG2EG:
# Convert to a list
xx <- as.list(org.Dm.egFLYBASECG2EG)
if(length(xx) > 0){
   # Gets the entrez gene IDs for the first five FlyBase CG IDs
   xx[1:5]
   # Get the first one
   xx[[1]]
}
}
\keyword{datasets}
